import { type Readable } from 'svelte/store';
import { type z } from 'zod';
import { ZodFieldStore } from './ZodFieldStore';
interface ICreateFormOptions<T> {
    /**
     * The initial value of fields in the form.
     */
    initialValue?: Partial<T>;
    /** Should return nothing, or an error message */
    onSubmit?: (v: T) => Promise<void | string> | string | void;
    /**
     * Debounce the value update (ms). Passing 0 to disable debounce
     * @default 0
     */
    debounceDelay?: number;
}
export declare class ZodFormStore<A extends z.ZodRawShape, O = A> {
    readonly model: Readable<O>;
    readonly options: ICreateFormOptions<O>;
    fields: {
        [K in keyof Required<O>]: ZodFieldStore<K, A, O>;
    };
    triggerSubmit: () => Promise<void>;
    reset: () => void;
    submitting: Readable<boolean>;
    errors: Readable<string[]>;
    error: Readable<string>;
    dirty: Readable<boolean>;
    constructor(schema: z.ZodObject<A, z.UnknownKeysParam, z.ZodTypeAny, O> | z.ZodEffects<z.ZodObject<A, z.UnknownKeysParam, z.ZodTypeAny, O>>, options?: ICreateFormOptions<O>);
    setError(errorMessage: string, path: (string | number)[]): void;
}
export {};
